@@ -1,11 +1,10 @@
 import re
 from io import BytesIO
+from urllib.request import urlopen
 
-from PIL import Image
-
+from PIL import Image, ImageFile
 from django.template.base import FilterExpression, kwarg_re
 
-
 DIM_REGEX = r'^(?P<v>(\d|\.)+)(?P<u>[a-z]*)$'
 
 DOCX_PAGE_WIDTH = 6120130
@@ -25,6 +24,12 @@ CONV_MAPPING = {
 }
 
 
+def size_to_odt(width, height):
+    width = CONV_MAPPING['px'](width)
+    height = CONV_MAPPING['px'](height)
+    return width, height
+
+
 def size_parser(dim, odt=True):
     """
     Convert `dxa`, `pt`, `px`, `in`, `cm`, `emu` to `dxa` if odt else to `emu`.
@@ -45,26 +50,6 @@ def size_parser(dim, odt=True):
         return CONV_MAPPING[unit](value) * 635
 
 
-def automatically_resize(bimage, odt=True):
-    """
-    Automatically resize the image to fit the page.
-
-    param bimage: an image.
-    :type bimage: bytes
-
-    :param odt: Optional
-    :type odt: boolean
-    """
-    buffer = BytesIO(bimage)
-    with Image.open(buffer) as img_reader:
-        width, height = img_reader.size
-        if odt:
-            ratio = min(ODT_PAGE_WIDTH / width, ODT_PAGE_HEIGHT / height)
-        else:
-            ratio = min(DOCX_PAGE_WIDTH / width, DOCX_PAGE_HEIGHT / height)
-        return (width * ratio), (height * ratio)
-
-
 def get_final_width_height(max_width, max_height, width, height):
     ratio = width / height
 
@@ -90,8 +75,7 @@ def resize_keep_ratio(bimage, max_width, max_height, odt=True):
         width, height = img_reader.size
 
     if odt:
-        width = width * 35.4 * 0.75
-        height = height * 35.4 * 0.75
+        width, height = size_to_odt(width, height)
 
     final_width, final_height = get_final_width_height(max_width, max_height, width, height)
 
@@ -100,7 +84,7 @@ def resize_keep_ratio(bimage, max_width, max_height, odt=True):
 
 def resize(bimage, max_width, max_height, odt=True):
     """
-    Automatically resize the image to fit the page. if no width or height has been specified,
+    Resize the image with max_width or/and max_height has been specified,
     otherwise convert them.
 
     :param bimage: an image.
@@ -116,8 +100,13 @@ def resize(bimage, max_width, max_height, odt=True):
     :type odt: boolean
     """
     if not max_width and not max_height:
-        width, height = automatically_resize(bimage, odt=odt)
+        buffer = BytesIO(bimage)
+        with Image.open(buffer) as img_reader:
+            width, height = img_reader.size
+            if odt:
+                width, height = size_to_odt(width, height)
         return width, height
+
     if max_width:
         max_width = size_parser(max_width, odt=odt)
     if max_height:
@@ -165,3 +154,35 @@ def parse_tag(token, parser):
             args.append(FilterExpression(bit, parser))
 
     return tag_name, args, kwargs
+
+
+def get_extension_picture(image):
+    bimage = BytesIO(image)
+    with Image.open(bimage) as img_reader:
+        extension = img_reader.format.lower()
+    return extension
+
+
+def get_image_size_and_dimensions_from_uri(uri):
+    """ get image size and dimensions """
+    if not uri.lower().startswith('http'):
+        # protect use of urlopen from filesystem read
+        return None, (None, None)
+
+    file = urlopen(uri)
+    size = file.headers.get("content-length")
+    dimensions = (None, None)
+
+    if size:
+        size = int(size)
+    p = ImageFile.Parser()
+    while True:
+        data = file.read(1024)
+        if not data:
+            break
+        p.feed(data)
+        if p.image:
+            dimensions = p.image.size
+            break
+    file.close()
+    return size, dimensions
